<?php

namespace Drupal\entity_value_inheritance;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;

/**
 * Provides a listing of inheritances.
 */
class InheritanceListBuilder extends ConfigEntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['label'] = $this->t('Label');
    $header['id'] = $this->t('Machine name');
    $header['status'] = $this->t('Status');
    $header['strategy'] = $this->t('Inherit Strategy');
    $header['source'] = $this->t('Source');
    $header['destination'] = $this->t('Destination');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    /** @var \Drupal\entity_value_inheritance\Entity\InheritanceInterface $entity */
    $row['label'] = $entity->label();
    $row['id'] = $entity->id();
    $row['status'] = $entity->status() ? $this->t('Enabled') : $this->t('Disabled');
    $row['strategy'] = $entity->getStrategy();
    $row['source'] = [
      'data' => [
        '#theme' => 'item_list',
        '#items' => [
          $this->t('Entity Type: @entity', ['@entity' => $entity->getSourceEntityType()]),
          $this->t('Bundle Type: @bundle', ['@bundle' => $entity->getSourceBundle()]),
          $this->t('Field: @field', ['@field' => $entity->getSourceField()]),
        ],
      ],
    ];

    $row['destination'] = [
      'data' => [
        '#theme' => 'item_list',
        '#items' => [
          $this->t('Entity Type: @entity', ['@entity' => $entity->getDestinationEntityType()]),
          $this->t('Bundle Type: @bundle', ['@bundle' => $entity->getDestinationBundle()]),
          $this->t('Field: @field', ['@field' => $entity->getDestinationField()]),
          $this->t('Reference Field: @field', ['@field' => $entity->getDestinationReferenceField()]),
        ],
      ],
    ];
    return $row + parent::buildRow($entity);
  }

}
